@@ -16,7 +16,8 @@ class GraphRNNEncoder(nn.Module):
                  fully_connected_layer_output_size: int,
                  device: str) -> None:
         super(GraphRNNEncoder, self).__init__()
-        base_tensor_shape = [number_of_node_features, number_of_node_features]
+        node_features_tensor_shape = [number_of_node_features, number_of_node_features]
+        nodes_tensor_shape = [number_of_nodes, number_of_nodes]
 
         self.time_steps = time_steps
         self.number_of_nodes = number_of_nodes
@@ -25,10 +26,10 @@ class GraphRNNEncoder(nn.Module):
         self.fully_connected_layer_output_size = fully_connected_layer_output_size
         self.device = device
 
-        self.w_graph_node_features = self._get_parameter(base_tensor_shape)
-        self.w_graph_neighbor_messages = self._get_parameter(base_tensor_shape)
-        self.u_graph_node_features = self._get_parameter(base_tensor_shape)
-        self.u_graph_neighbor_messages = self._get_parameter(base_tensor_shape)
+        self.w_graph_node_features = self._get_parameter(node_features_tensor_shape)
+        self.w_graph_neighbor_messages = self._get_parameter(node_features_tensor_shape)
+        self.u_graph_node_features = self._get_parameter(nodes_tensor_shape)
+        self.u_graph_neighbor_messages = self._get_parameter(node_features_tensor_shape)
         self.linear = to.nn.Linear(self.fully_connected_layer_input_size, self.fully_connected_layer_output_size)
         self.sigmoid = to.nn.Sigmoid()
 
@@ -73,10 +74,11 @@ class GraphRNNEncoder(nn.Module):
         return messages
 
     def _encode_nodes(self, node_features: to.Tensor, messages: to.Tensor) -> to.Tensor:
-        encoded_node = to.zeros(self.number_of_nodes, self.number_of_node_features, device=self.device)
+        node_encoding_messages = to.zeros(self.number_of_nodes, self.number_of_node_features, device=self.device)
+        node_encoding_features = self.u_graph_node_features.matmul(node_features)
         for node_id in range(self.number_of_nodes):
-            encoded_node[node_id] = self._apply_recurrent_layer(node_features, messages, node_id)
-        return encoded_node
+            node_encoding_messages[node_id] = self.u_graph_neighbor_messages.matmul(to.sum(messages[node_id], dim=0))
+        return to.relu(node_encoding_features + node_encoding_messages)
 
     def _apply_recurrent_layer(self, node_features: to.Tensor, messages: to.Tensor, node_id: int) -> to.Tensor:
         node_encoding_features = self.u_graph_node_features.matmul(node_features[node_id])
@@ -90,11 +92,9 @@ class GraphRNNEncoder(nn.Module):
         new_messages = to.zeros(messages.shape, device=self.device)
         for node_id in range(self.number_of_nodes):
             node = self._create_node(node_features, adjacency_matrix, node_id)
-            for end_node_id in node.neighbors:
+            for end_node_id in node.all_neighbors:
                 message = self._get_message_value(messages, node, end_node_id, node_features)
                 new_messages[node_id, end_node_id] = message
-                if Node.is_adjacency_matrix_symmetric(adjacency_matrix):
-                    new_messages[end_node_id, node_id] = message
         return new_messages
 
     def _get_message_value(self, messages: to.Tensor, node: Node, end_node_id: int, node_features: to.Tensor) \
